# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/ai/v1/endpoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.compute.v1 import disk_pb2 as nebius_dot_compute_dot_v1_dot_disk__pb2
from nebius.api.nebius.compute.v1 import instance_pb2 as nebius_dot_compute_dot_v1_dot_instance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bnebius/ai/v1/endpoint.proto\x12\x0cnebius.ai.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x1cnebius/compute/v1/disk.proto\x1a nebius/compute/v1/instance.proto\"\xc6\x01\n\x08\x45ndpoint\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x36\n\x04spec\x18\x02 \x01(\x0b\x32\x1a.nebius.ai.v1.EndpointSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12:\n\x06status\x18\x03 \x01(\x0b\x32\x1c.nebius.ai.v1.EndpointStatusB\x04\xbaJ\x01\x05R\x06status\"\x91\r\n\x0c\x45ndpointSpec\x12\x1c\n\x05image\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05image\x12\x63\n\x15\x65nvironment_variables\x18\x02 \x03(\x0b\x32..nebius.ai.v1.EndpointSpec.EnvironmentVariableR\x14\x65nvironmentVariables\x12\x35\n\x05ports\x18\x03 \x03(\x0b\x32\x1f.nebius.ai.v1.EndpointSpec.PortR\x05ports\x12+\n\x11\x63ontainer_command\x18\x04 \x01(\tR\x10\x63ontainerCommand\x12\x12\n\x04\x61rgs\x18\x05 \x01(\tR\x04\x61rgs\x12)\n\x0bworking_dir\x18\x06 \x01(\tB\x08\xbaH\x05r\x03\x18\x80\x01R\nworkingDir\x12@\n\x07volumes\x18\x07 \x03(\x0b\x32&.nebius.ai.v1.EndpointSpec.VolumeMountR\x07volumes\x12\x61\n\x14registry_credentials\x18\n \x01(\x0b\x32..nebius.ai.v1.EndpointSpec.RegistryCredentialsR\x13registryCredentials\x12\"\n\x08platform\x18\x14 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08platform\x12\x1e\n\x06preset\x18\x15 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x06preset\x12-\n\x0eshm_size_bytes\x18\x16 \x01(\x03\x42\x07\xbaH\x04\"\x02(\x00R\x0cshmSizeBytes\x12?\n\x04\x64isk\x18\x17 \x01(\x0b\x32#.nebius.ai.v1.EndpointSpec.DiskSpecB\x06\xbaH\x03\xc8\x01\x01R\x04\x64isk\x12\x31\n\tsubnet_id\x18\x18 \x01(\tB\x14\xbaH\x03\xc8\x01\x01\xe2J\x0b\n\tvpcsubnetR\x08subnetId\x12\x1b\n\tpublic_ip\x18\x19 \x01(\x08R\x08publicIp\x12.\n\x13ssh_authorized_keys\x18\x1a \x03(\tR\x11sshAuthorizedKeys\x12\"\n\nauth_token\x18\x1e \x01(\tB\x03\xc0J\x01R\tauthToken\x1aL\n\x13\x45nvironmentVariable\x12\x1a\n\x04name\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\x12\x19\n\x05value\x18\x02 \x01(\tB\x03\xc0J\x01R\x05value\x1a\xf4\x01\n\x04Port\x12\x32\n\x0e\x63ontainer_port\x18\x01 \x01(\x05\x42\x0b\xbaH\x08\x1a\x06\x18\xff\xff\x03(\x01R\rcontainerPort\x12(\n\thost_port\x18\x02 \x01(\x05\x42\x0b\xbaH\x08\x1a\x06\x18\xff\xff\x03(\x00R\x08hostPort\x12L\n\x08protocol\x18\x03 \x01(\x0e\x32(.nebius.ai.v1.EndpointSpec.Port.ProtocolB\x06\xbaH\x03\xc8\x01\x01R\x08protocol\"@\n\x08Protocol\x12\x18\n\x14PROTOCOL_UNSPECIFIED\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\x07\n\x03TCP\x10\x02\x12\x07\n\x03UDP\x10\x03\x1a\x9a\x02\n\x0bVolumeMount\x12=\n\x06source\x18\x01 \x01(\tB%\xe2J\"\n\x11\x63omputefilesystem\n\rstoragebucketR\x06source\x12\x1f\n\x0bsource_path\x18\x02 \x01(\tR\nsourcePath\x12%\n\x0e\x63ontainer_path\x18\x03 \x01(\tR\rcontainerPath\x12G\n\x04mode\x18\x04 \x01(\x0e\x32+.nebius.ai.v1.EndpointSpec.VolumeMount.ModeB\x06\xbaH\x03\xc8\x01\x01R\x04mode\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\x1ak\n\x08\x44iskSpec\x12@\n\x04type\x18\x01 \x01(\x0e\x32$.nebius.compute.v1.DiskSpec.DiskTypeB\x06\xbaH\x03\xc8\x01\x01R\x04type\x12\x1d\n\nsize_bytes\x18\x02 \x01(\x03R\tsizeBytes\x1a\x8e\x01\n\x13RegistryCredentials\x12\x1a\n\x08username\x18\x01 \x01(\tR\x08username\x12\x1f\n\x08password\x18\x02 \x01(\tB\x03\xc0J\x01R\x08password\x12:\n\x19mysterybox_secret_version\x18\x03 \x01(\tR\x17mysteryboxSecretVersion\"\xb0\x03\n\x0e\x45ndpointStatus\x12+\n\x11private_endpoints\x18\x01 \x03(\tR\x10privateEndpoints\x12)\n\x10public_endpoints\x18\x02 \x03(\tR\x0fpublicEndpoints\x12\x42\n\tinstances\x18\n \x03(\x0b\x32$.nebius.ai.v1.EndpointInstanceStatusR\tinstances\x12\x38\n\x05state\x18\x14 \x01(\x0e\x32\".nebius.ai.v1.EndpointStatus.StateR\x05state\x12G\n\rstate_details\x18\x15 \x01(\x0b\x32\".nebius.ai.v1.EndpointStateDetailsR\x0cstateDetails\"\x7f\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0c\n\x08STARTING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\t\n\x05\x45RROR\x10\x08\"L\n\x14\x45ndpointStateDetails\x12\x1a\n\x04\x63ode\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"\xd9\x03\n\x16\x45ndpointInstanceStatus\x12H\n\x05state\x18\x01 \x01(\x0e\x32*.nebius.ai.v1.EndpointInstanceStatus.StateB\x06\xbaH\x03\xc8\x01\x01R\x05state\x12\x44\n\x13\x63ompute_instance_id\x18\n \x01(\tB\x14\xe2J\x11\n\x0f\x63omputeinstanceR\x11\x63omputeInstanceId\x12\x65\n\x16\x63ompute_instance_state\x18\x0b \x01(\x0e\x32/.nebius.compute.v1.InstanceStatus.InstanceStateR\x14\x63omputeInstanceState\x12\x1d\n\nprivate_ip\x18\x0c \x01(\tR\tprivateIp\x12\x1b\n\tpublic_ip\x18\r \x01(\tR\x08publicIp\"\x8b\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0c\n\x08STARTING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\n\n\x06\x46\x41ILED\x10\x07\x12\t\n\x05\x45RROR\x10\x08\x42R\n\x13\x61i.nebius.pub.ai.v1B\rEndpointProtoP\x01Z*github.com/nebius/gosdk/proto/nebius/ai/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.ai.v1.endpoint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023ai.nebius.pub.ai.v1B\rEndpointProtoP\001Z*github.com/nebius/gosdk/proto/nebius/ai/v1'
  _ENDPOINT.fields_by_name['metadata']._options = None
  _ENDPOINT.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINT.fields_by_name['spec']._options = None
  _ENDPOINT.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINT.fields_by_name['status']._options = None
  _ENDPOINT.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _ENDPOINTSPEC_ENVIRONMENTVARIABLE.fields_by_name['name']._options = None
  _ENDPOINTSPEC_ENVIRONMENTVARIABLE.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTSPEC_ENVIRONMENTVARIABLE.fields_by_name['value']._options = None
  _ENDPOINTSPEC_ENVIRONMENTVARIABLE.fields_by_name['value']._serialized_options = b'\300J\001'
  _ENDPOINTSPEC_PORT.fields_by_name['container_port']._options = None
  _ENDPOINTSPEC_PORT.fields_by_name['container_port']._serialized_options = b'\272H\010\032\006\030\377\377\003(\001'
  _ENDPOINTSPEC_PORT.fields_by_name['host_port']._options = None
  _ENDPOINTSPEC_PORT.fields_by_name['host_port']._serialized_options = b'\272H\010\032\006\030\377\377\003(\000'
  _ENDPOINTSPEC_PORT.fields_by_name['protocol']._options = None
  _ENDPOINTSPEC_PORT.fields_by_name['protocol']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTSPEC_VOLUMEMOUNT.fields_by_name['source']._options = None
  _ENDPOINTSPEC_VOLUMEMOUNT.fields_by_name['source']._serialized_options = b'\342J\"\n\021computefilesystem\n\rstoragebucket'
  _ENDPOINTSPEC_VOLUMEMOUNT.fields_by_name['mode']._options = None
  _ENDPOINTSPEC_VOLUMEMOUNT.fields_by_name['mode']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTSPEC_DISKSPEC.fields_by_name['type']._options = None
  _ENDPOINTSPEC_DISKSPEC.fields_by_name['type']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTSPEC_REGISTRYCREDENTIALS.fields_by_name['password']._options = None
  _ENDPOINTSPEC_REGISTRYCREDENTIALS.fields_by_name['password']._serialized_options = b'\300J\001'
  _ENDPOINTSPEC.fields_by_name['image']._options = None
  _ENDPOINTSPEC.fields_by_name['image']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTSPEC.fields_by_name['working_dir']._options = None
  _ENDPOINTSPEC.fields_by_name['working_dir']._serialized_options = b'\272H\005r\003\030\200\001'
  _ENDPOINTSPEC.fields_by_name['platform']._options = None
  _ENDPOINTSPEC.fields_by_name['platform']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTSPEC.fields_by_name['preset']._options = None
  _ENDPOINTSPEC.fields_by_name['preset']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTSPEC.fields_by_name['shm_size_bytes']._options = None
  _ENDPOINTSPEC.fields_by_name['shm_size_bytes']._serialized_options = b'\272H\004\"\002(\000'
  _ENDPOINTSPEC.fields_by_name['disk']._options = None
  _ENDPOINTSPEC.fields_by_name['disk']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTSPEC.fields_by_name['subnet_id']._options = None
  _ENDPOINTSPEC.fields_by_name['subnet_id']._serialized_options = b'\272H\003\310\001\001\342J\013\n\tvpcsubnet'
  _ENDPOINTSPEC.fields_by_name['auth_token']._options = None
  _ENDPOINTSPEC.fields_by_name['auth_token']._serialized_options = b'\300J\001'
  _ENDPOINTSTATEDETAILS.fields_by_name['code']._options = None
  _ENDPOINTSTATEDETAILS.fields_by_name['code']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTINSTANCESTATUS.fields_by_name['state']._options = None
  _ENDPOINTINSTANCESTATUS.fields_by_name['state']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTINSTANCESTATUS.fields_by_name['compute_instance_id']._options = None
  _ENDPOINTINSTANCESTATUS.fields_by_name['compute_instance_id']._serialized_options = b'\342J\021\n\017computeinstance'
  _globals['_ENDPOINT']._serialized_start=198
  _globals['_ENDPOINT']._serialized_end=396
  _globals['_ENDPOINTSPEC']._serialized_start=399
  _globals['_ENDPOINTSPEC']._serialized_end=2080
  _globals['_ENDPOINTSPEC_ENVIRONMENTVARIABLE']._serialized_start=1218
  _globals['_ENDPOINTSPEC_ENVIRONMENTVARIABLE']._serialized_end=1294
  _globals['_ENDPOINTSPEC_PORT']._serialized_start=1297
  _globals['_ENDPOINTSPEC_PORT']._serialized_end=1541
  _globals['_ENDPOINTSPEC_PORT_PROTOCOL']._serialized_start=1477
  _globals['_ENDPOINTSPEC_PORT_PROTOCOL']._serialized_end=1541
  _globals['_ENDPOINTSPEC_VOLUMEMOUNT']._serialized_start=1544
  _globals['_ENDPOINTSPEC_VOLUMEMOUNT']._serialized_end=1826
  _globals['_ENDPOINTSPEC_VOLUMEMOUNT_MODE']._serialized_start=1767
  _globals['_ENDPOINTSPEC_VOLUMEMOUNT_MODE']._serialized_end=1826
  _globals['_ENDPOINTSPEC_DISKSPEC']._serialized_start=1828
  _globals['_ENDPOINTSPEC_DISKSPEC']._serialized_end=1935
  _globals['_ENDPOINTSPEC_REGISTRYCREDENTIALS']._serialized_start=1938
  _globals['_ENDPOINTSPEC_REGISTRYCREDENTIALS']._serialized_end=2080
  _globals['_ENDPOINTSTATUS']._serialized_start=2083
  _globals['_ENDPOINTSTATUS']._serialized_end=2515
  _globals['_ENDPOINTSTATUS_STATE']._serialized_start=2388
  _globals['_ENDPOINTSTATUS_STATE']._serialized_end=2515
  _globals['_ENDPOINTSTATEDETAILS']._serialized_start=2517
  _globals['_ENDPOINTSTATEDETAILS']._serialized_end=2593
  _globals['_ENDPOINTINSTANCESTATUS']._serialized_start=2596
  _globals['_ENDPOINTINSTANCESTATUS']._serialized_end=3069
  _globals['_ENDPOINTINSTANCESTATUS_STATE']._serialized_start=2930
  _globals['_ENDPOINTINSTANCESTATUS_STATE']._serialized_end=3069
# @@protoc_insertion_point(module_scope)
