# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/capacity/v1/resource_affinity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*nebius/capacity/v1/resource_affinity.proto\x12\x12nebius.capacity.v1\x1a\x1b\x62uf/validate/validate.proto\"W\n\x19ResourceAffinityComputeV1\x12\x16\n\x06\x66\x61\x62ric\x18\x01 \x01(\tR\x06\x66\x61\x62ric\x12\"\n\x08platform\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08platform\"n\n\x10ResourceAffinity\x12N\n\ncompute_v1\x18\x01 \x01(\x0b\x32-.nebius.capacity.v1.ResourceAffinityComputeV1H\x00R\tcomputeV1B\n\n\x08versionsBf\n\x19\x61i.nebius.pub.capacity.v1B\x15ResourceAffinityProtoP\x01Z0github.com/nebius/gosdk/proto/nebius/capacity/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.capacity.v1.resource_affinity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031ai.nebius.pub.capacity.v1B\025ResourceAffinityProtoP\001Z0github.com/nebius/gosdk/proto/nebius/capacity/v1'
  _RESOURCEAFFINITYCOMPUTEV1.fields_by_name['platform']._options = None
  _RESOURCEAFFINITYCOMPUTEV1.fields_by_name['platform']._serialized_options = b'\272H\003\310\001\001'
  _globals['_RESOURCEAFFINITYCOMPUTEV1']._serialized_start=95
  _globals['_RESOURCEAFFINITYCOMPUTEV1']._serialized_end=182
  _globals['_RESOURCEAFFINITY']._serialized_start=184
  _globals['_RESOURCEAFFINITY']._serialized_end=294
# @@protoc_insertion_point(module_scope)
