# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1/image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dnebius/compute/v1/image.proto\x12\x11nebius.compute.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xb1\x01\n\x05Image\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.nebius.compute.v1.ImageSpecR\x04spec\x12\x36\n\x06status\x18\x03 \x01(\x0b\x32\x1e.nebius.compute.v1.ImageStatusR\x06status\"\xca\x05\n\tImageSpec\x12P\n\x0b\x64\x65scription\x18\x01 \x01(\tB)\x18\x01\xbaJ\x01\x02\xd2J \n\n2026-01-01\x12\x12The field is emptyH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\'\n\x0cimage_family\x18\x02 \x01(\tB\x04\xbaJ\x01\x02R\x0bimageFamily\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xbaJ\x01\x02R\x07version\x12,\n\x0esource_disk_id\x18\x04 \x01(\tB\x04\xbaJ\x01\x02H\x00R\x0csourceDiskId\x12]\n\x10\x63pu_architecture\x18\x06 \x01(\x0e\x32,.nebius.compute.v1.ImageSpec.CPUArchitectureB\x04\xbaJ\x01\x02R\x0f\x63puArchitecture\x12\x43\n\x1bimage_family_human_readable\x18\x07 \x01(\tB\x04\xbaJ\x01\x02R\x18imageFamilyHumanReadable\x12\x39\n\x15recommended_platforms\x18\x08 \x03(\tB\x04\xbaJ\x01\x02R\x14recommendedPlatforms\x12q\n\x15unsupported_platforms\x18\t \x03(\x0b\x32\x36.nebius.compute.v1.ImageSpec.UnsupportedPlatformsEntryB\x04\xbaJ\x01\x02R\x14unsupportedPlatforms\x1aG\n\x19UnsupportedPlatformsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"8\n\x0f\x43PUArchitecture\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\t\n\x05\x41MD64\x10\x01\x12\t\n\x05\x41RM64\x10\x02\x42\x0f\n\x06source\x12\x05\xbaH\x02\x08\x01\x42\x0e\n\x0c_description\"\xc1\x04\n\x0bImageStatus\x12:\n\x05state\x18\x01 \x01(\x0e\x32$.nebius.compute.v1.ImageStatus.StateR\x05state\x12+\n\x11state_description\x18\x02 \x01(\tR\x10stateDescription\x12,\n\x12storage_size_bytes\x18\x03 \x01(\x03R\x10storageSizeBytes\x12-\n\x13min_disk_size_bytes\x18\x04 \x01(\x03R\x10minDiskSizeBytes\x12 \n\x0breconciling\x18\x05 \x01(\x08R\x0breconciling\x12u\n\x18image_family_deprecation\x18\x06 \x01(\x0b\x32;.nebius.compute.v1.ImageStatus.ImageFamilyDeprecationStatusR\x16imageFamilyDeprecation\x1ay\n\x1cImageFamilyDeprecationStatus\x12?\n\rdeprecated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x64\x65precatedAt\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"X\n\x05State\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x42Y\n\x18\x61i.nebius.pub.compute.v1B\nImageProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/compute/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1.image_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.compute.v1B\nImageProtoP\001Z/github.com/nebius/gosdk/proto/nebius/compute/v1'
  _IMAGESPEC_UNSUPPORTEDPLATFORMSENTRY._options = None
  _IMAGESPEC_UNSUPPORTEDPLATFORMSENTRY._serialized_options = b'8\001'
  _IMAGESPEC.oneofs_by_name['source']._options = None
  _IMAGESPEC.oneofs_by_name['source']._serialized_options = b'\272H\002\010\001'
  _IMAGESPEC.fields_by_name['description']._options = None
  _IMAGESPEC.fields_by_name['description']._serialized_options = b'\030\001\272J\001\002\322J \n\n2026-01-01\022\022The field is empty'
  _IMAGESPEC.fields_by_name['image_family']._options = None
  _IMAGESPEC.fields_by_name['image_family']._serialized_options = b'\272J\001\002'
  _IMAGESPEC.fields_by_name['version']._options = None
  _IMAGESPEC.fields_by_name['version']._serialized_options = b'\272J\001\002'
  _IMAGESPEC.fields_by_name['source_disk_id']._options = None
  _IMAGESPEC.fields_by_name['source_disk_id']._serialized_options = b'\272J\001\002'
  _IMAGESPEC.fields_by_name['cpu_architecture']._options = None
  _IMAGESPEC.fields_by_name['cpu_architecture']._serialized_options = b'\272J\001\002'
  _IMAGESPEC.fields_by_name['image_family_human_readable']._options = None
  _IMAGESPEC.fields_by_name['image_family_human_readable']._serialized_options = b'\272J\001\002'
  _IMAGESPEC.fields_by_name['recommended_platforms']._options = None
  _IMAGESPEC.fields_by_name['recommended_platforms']._serialized_options = b'\272J\001\002'
  _IMAGESPEC.fields_by_name['unsupported_platforms']._options = None
  _IMAGESPEC.fields_by_name['unsupported_platforms']._serialized_options = b'\272J\001\002'
  _globals['_IMAGE']._serialized_start=174
  _globals['_IMAGE']._serialized_end=351
  _globals['_IMAGESPEC']._serialized_start=354
  _globals['_IMAGESPEC']._serialized_end=1068
  _globals['_IMAGESPEC_UNSUPPORTEDPLATFORMSENTRY']._serialized_start=906
  _globals['_IMAGESPEC_UNSUPPORTEDPLATFORMSENTRY']._serialized_end=977
  _globals['_IMAGESPEC_CPUARCHITECTURE']._serialized_start=979
  _globals['_IMAGESPEC_CPUARCHITECTURE']._serialized_end=1035
  _globals['_IMAGESTATUS']._serialized_start=1071
  _globals['_IMAGESTATUS']._serialized_end=1648
  _globals['_IMAGESTATUS_IMAGEFAMILYDEPRECATIONSTATUS']._serialized_start=1437
  _globals['_IMAGESTATUS_IMAGEFAMILYDEPRECATIONSTATUS']._serialized_end=1558
  _globals['_IMAGESTATUS_STATE']._serialized_start=1560
  _globals['_IMAGESTATUS_STATE']._serialized_end=1648
# @@protoc_insertion_point(module_scope)
