# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.ai.v1 import endpoint_pb2 as nebius_dot_ai_dot_v1_dot_endpoint__pb2
from nebius.api.nebius.ai.v1 import endpoint_service_pb2 as nebius_dot_ai_dot_v1_dot_endpoint__service__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2


class EndpointServiceStub(object):
    """Service to create/manage endpoints.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/nebius.ai.v1.EndpointService/Get',
                request_serializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.GetEndpointRequest.SerializeToString,
                response_deserializer=nebius_dot_ai_dot_v1_dot_endpoint__pb2.Endpoint.FromString,
                )
        self.GetByName = channel.unary_unary(
                '/nebius.ai.v1.EndpointService/GetByName',
                request_serializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.GetEndpointByNameRequest.SerializeToString,
                response_deserializer=nebius_dot_ai_dot_v1_dot_endpoint__pb2.Endpoint.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.ai.v1.EndpointService/List',
                request_serializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.ListEndpointsRequest.SerializeToString,
                response_deserializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.ListEndpointsResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/nebius.ai.v1.EndpointService/Create',
                request_serializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.CreateEndpointRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.ai.v1.EndpointService/Delete',
                request_serializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.DeleteEndpointRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/nebius.ai.v1.EndpointService/Update',
                request_serializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.UpdateEndpointRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Start = channel.unary_unary(
                '/nebius.ai.v1.EndpointService/Start',
                request_serializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.StartEndpointRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Stop = channel.unary_unary(
                '/nebius.ai.v1.EndpointService/Stop',
                request_serializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.StopEndpointRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )


class EndpointServiceServicer(object):
    """Service to create/manage endpoints.
    """

    def Get(self, request, context):
        """Returns the specified endpoint.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByName(self, request, context):
        """Returns the specified endpoint by name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves a list of endpoints.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates an endpoint.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes an endpoint.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates an endpoint.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Start(self, request, context):
        """Starts an endpoint.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """Stops an endpoint.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EndpointServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.GetEndpointRequest.FromString,
                    response_serializer=nebius_dot_ai_dot_v1_dot_endpoint__pb2.Endpoint.SerializeToString,
            ),
            'GetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByName,
                    request_deserializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.GetEndpointByNameRequest.FromString,
                    response_serializer=nebius_dot_ai_dot_v1_dot_endpoint__pb2.Endpoint.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.ListEndpointsRequest.FromString,
                    response_serializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.ListEndpointsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.CreateEndpointRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.DeleteEndpointRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.UpdateEndpointRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.StartEndpointRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.StopEndpointRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.ai.v1.EndpointService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EndpointService(object):
    """Service to create/manage endpoints.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.ai.v1.EndpointService/Get',
            nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.GetEndpointRequest.SerializeToString,
            nebius_dot_ai_dot_v1_dot_endpoint__pb2.Endpoint.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.ai.v1.EndpointService/GetByName',
            nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.GetEndpointByNameRequest.SerializeToString,
            nebius_dot_ai_dot_v1_dot_endpoint__pb2.Endpoint.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.ai.v1.EndpointService/List',
            nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.ListEndpointsRequest.SerializeToString,
            nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.ListEndpointsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.ai.v1.EndpointService/Create',
            nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.CreateEndpointRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.ai.v1.EndpointService/Delete',
            nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.DeleteEndpointRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.ai.v1.EndpointService/Update',
            nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.UpdateEndpointRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.ai.v1.EndpointService/Start',
            nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.StartEndpointRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.ai.v1.EndpointService/Stop',
            nebius_dot_ai_dot_v1_dot_endpoint__service__pb2.StopEndpointRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
