from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius.common.v1 import operation_pb2 as _operation_pb2
from nebius.api.nebius.iam.v1 import federation_certificate_pb2 as _federation_certificate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateFederationCertificateRequest(_message.Message):
    __slots__ = ["metadata", "spec"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: _federation_certificate_pb2.FederationCertificateSpec
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[_federation_certificate_pb2.FederationCertificateSpec, _Mapping]] = ...) -> None: ...

class GetFederationCertificateRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ListFederationCertificateByFederationRequest(_message.Message):
    __slots__ = ["federation_id", "page_size", "page_token"]
    FEDERATION_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    federation_id: str
    page_size: int
    page_token: str
    def __init__(self, federation_id: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class UpdateFederationCertificateRequest(_message.Message):
    __slots__ = ["metadata", "spec"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: _federation_certificate_pb2.FederationCertificateSpec
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[_federation_certificate_pb2.FederationCertificateSpec, _Mapping]] = ...) -> None: ...

class UpdateBulkFederationCertificateRequest(_message.Message):
    __slots__ = ["federation_id", "updates"]
    FEDERATION_ID_FIELD_NUMBER: _ClassVar[int]
    UPDATES_FIELD_NUMBER: _ClassVar[int]
    federation_id: str
    updates: _containers.RepeatedCompositeFieldContainer[UpdateFederationCertificateRequest]
    def __init__(self, federation_id: _Optional[str] = ..., updates: _Optional[_Iterable[_Union[UpdateFederationCertificateRequest, _Mapping]]] = ...) -> None: ...

class DeleteFederationCertificateRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ListFederationCertificateResponse(_message.Message):
    __slots__ = ["items", "next_page_token"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_federation_certificate_pb2.FederationCertificate]
    next_page_token: str
    def __init__(self, items: _Optional[_Iterable[_Union[_federation_certificate_pb2.FederationCertificate, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...
