# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/capacity/v1/capacity_interval.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.capacity.v1 import resource_affinity_pb2 as nebius_dot_capacity_dot_v1_dot_resource__affinity__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*nebius/capacity/v1/capacity_interval.proto\x12\x12nebius.capacity.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18nebius/annotations.proto\x1a*nebius/capacity/v1/resource_affinity.proto\x1a\x1fnebius/common/v1/metadata.proto\"\x16\n\x14\x43\x61pacityIntervalSpec\"\x9f\x04\n\x16\x43\x61pacityIntervalStatus\x12.\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x0b\xe2J\x08\n\x06tenantR\x0b\x63ontainerId\x12\x16\n\x06region\x18\x02 \x01(\tR\x06region\x12Q\n\x11resource_affinity\x18\x03 \x01(\x0b\x32$.nebius.capacity.v1.ResourceAffinityR\x10resourceAffinity\x12\x18\n\x07service\x18\x04 \x01(\tR\x07service\x12\x1a\n\x08quantity\x18\x05 \x01(\x04R\x08quantity\x12\x39\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\x46\n\x05state\x18\x08 \x01(\x0e\x32\x30.nebius.capacity.v1.CapacityIntervalStatus.StateR\x05state\x12 \n\x0breconciling\x18\x64 \x01(\x08R\x0breconciling\"X\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSTATE_SCHEDULED\x10\x01\x12\x10\n\x0cSTATE_ACTIVE\x10\x02\x12\x11\n\rSTATE_EXPIRED\x10\x03\"\x87\x02\n\x10\x43\x61pacityInterval\x12]\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x1d\xbaH\x03\xc8\x01\x01\xe2J\x14\x12\x12\x63\x61pacityblockgroupR\x08metadata\x12\x44\n\x04spec\x18\x02 \x01(\x0b\x32(.nebius.capacity.v1.CapacityIntervalSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12H\n\x06status\x18\x03 \x01(\x0b\x32*.nebius.capacity.v1.CapacityIntervalStatusB\x04\xbaJ\x01\x05R\x06status:\x04\xbaJ\x01\x02\x42\x66\n\x19\x61i.nebius.pub.capacity.v1B\x15\x43\x61pacityIntervalProtoP\x01Z0github.com/nebius/gosdk/proto/nebius/capacity/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.capacity.v1.capacity_interval_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031ai.nebius.pub.capacity.v1B\025CapacityIntervalProtoP\001Z0github.com/nebius/gosdk/proto/nebius/capacity/v1'
  _CAPACITYINTERVALSTATUS.fields_by_name['container_id']._options = None
  _CAPACITYINTERVALSTATUS.fields_by_name['container_id']._serialized_options = b'\342J\010\n\006tenant'
  _CAPACITYINTERVAL.fields_by_name['metadata']._options = None
  _CAPACITYINTERVAL.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001\342J\024\022\022capacityblockgroup'
  _CAPACITYINTERVAL.fields_by_name['spec']._options = None
  _CAPACITYINTERVAL.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _CAPACITYINTERVAL.fields_by_name['status']._options = None
  _CAPACITYINTERVAL.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _CAPACITYINTERVAL._options = None
  _CAPACITYINTERVAL._serialized_options = b'\272J\001\002'
  _globals['_CAPACITYINTERVALSPEC']._serialized_start=231
  _globals['_CAPACITYINTERVALSPEC']._serialized_end=253
  _globals['_CAPACITYINTERVALSTATUS']._serialized_start=256
  _globals['_CAPACITYINTERVALSTATUS']._serialized_end=799
  _globals['_CAPACITYINTERVALSTATUS_STATE']._serialized_start=711
  _globals['_CAPACITYINTERVALSTATUS_STATE']._serialized_end=799
  _globals['_CAPACITYINTERVAL']._serialized_start=802
  _globals['_CAPACITYINTERVAL']._serialized_end=1065
# @@protoc_insertion_point(module_scope)
