# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/common/v1/progress_tracker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'nebius/common/v1/progress_tracker.proto\x12\x10nebius.common.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfe\x05\n\x0fProgressTracker\x12(\n\x0b\x64\x65scription\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0b\x64\x65scription\x12\x41\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\tstartedAt\x12N\n\x15\x65stimated_finished_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13\x65stimatedFinishedAt\x12;\n\x0b\x66inished_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nfinishedAt\x12G\n\twork_done\x18\n \x01(\x0b\x32*.nebius.common.v1.ProgressTracker.WorkDoneR\x08workDone\x12<\n\x05steps\x18\x14 \x03(\x0b\x32&.nebius.common.v1.ProgressTracker.StepR\x05steps\x1an\n\x08WorkDone\x12\x31\n\x10total_tick_count\x18\x01 \x01(\x03\x42\x07\xbaH\x04\"\x02 \x00R\x0etotalTickCount\x12/\n\x0f\x64one_tick_count\x18\x02 \x01(\x03\x42\x07\xbaH\x04\"\x02(\x00R\rdoneTickCount\x1a\xf9\x01\n\x04Step\x12(\n\x0b\x64\x65scription\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0b\x64\x65scription\x12\x41\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\tstartedAt\x12;\n\x0b\x66inished_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nfinishedAt\x12G\n\twork_done\x18\n \x01(\x0b\x32*.nebius.common.v1.ProgressTracker.WorkDoneR\x08workDoneBa\n\x17\x61i.nebius.pub.common.v1B\x14ProgressTrackerProtoP\x01Z.github.com/nebius/gosdk/proto/nebius/common/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.common.v1.progress_tracker_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027ai.nebius.pub.common.v1B\024ProgressTrackerProtoP\001Z.github.com/nebius/gosdk/proto/nebius/common/v1'
  _PROGRESSTRACKER_WORKDONE.fields_by_name['total_tick_count']._options = None
  _PROGRESSTRACKER_WORKDONE.fields_by_name['total_tick_count']._serialized_options = b'\272H\004\"\002 \000'
  _PROGRESSTRACKER_WORKDONE.fields_by_name['done_tick_count']._options = None
  _PROGRESSTRACKER_WORKDONE.fields_by_name['done_tick_count']._serialized_options = b'\272H\004\"\002(\000'
  _PROGRESSTRACKER_STEP.fields_by_name['description']._options = None
  _PROGRESSTRACKER_STEP.fields_by_name['description']._serialized_options = b'\272H\003\310\001\001'
  _PROGRESSTRACKER_STEP.fields_by_name['started_at']._options = None
  _PROGRESSTRACKER_STEP.fields_by_name['started_at']._serialized_options = b'\272H\003\310\001\001'
  _PROGRESSTRACKER.fields_by_name['description']._options = None
  _PROGRESSTRACKER.fields_by_name['description']._serialized_options = b'\272H\003\310\001\001'
  _PROGRESSTRACKER.fields_by_name['started_at']._options = None
  _PROGRESSTRACKER.fields_by_name['started_at']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PROGRESSTRACKER']._serialized_start=124
  _globals['_PROGRESSTRACKER']._serialized_end=890
  _globals['_PROGRESSTRACKER_WORKDONE']._serialized_start=528
  _globals['_PROGRESSTRACKER_WORKDONE']._serialized_end=638
  _globals['_PROGRESSTRACKER_STEP']._serialized_start=641
  _globals['_PROGRESSTRACKER_STEP']._serialized_end=890
# @@protoc_insertion_point(module_scope)
