# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/audit_event_export.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.audit.v2 import audit_event_service_pb2 as nebius_dot_audit_dot_v2_dot_audit__event__service__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/audit/v2/audit_event_export.proto\x12\x0fnebius.audit.v2\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18nebius/annotations.proto\x1a)nebius/audit/v2/audit_event_service.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xce\x01\n\x10\x41uditEventExport\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x39\n\x04spec\x18\x02 \x01(\x0b\x32%.nebius.audit.v2.AuditEventExportSpecR\x04spec\x12?\n\x06status\x18\x03 \x01(\x0b\x32\'.nebius.audit.v2.AuditEventExportStatusR\x06status\"\xe3\x01\n\x14\x41uditEventExportSpec\x12G\n\x06params\x18\x01 \x01(\x0b\x32\'.nebius.audit.v2.AuditEventExportParamsB\x06\xbaH\x03\xc8\x01\x01R\x06params\x12\x65\n\x15nebius_object_storage\x18\x02 \x01(\x0b\x32/.nebius.audit.v2.NebiusObjectStorageDestinationH\x00R\x13nebiusObjectStorageB\x1b\n\x12\x65xport_destination\x12\x05\xbaH\x02\x08\x01\"\x97\x01\n\x1eNebiusObjectStorageDestination\x12#\n\robject_prefix\x18\x01 \x01(\tR\x0cobjectPrefix\x12?\n\x0c\x62ucket_by_id\x18\x02 \x01(\x0b\x32\x1b.nebius.audit.v2.BucketByIdH\x00R\nbucketByIdB\x0f\n\x06\x62ucket\x12\x05\xbaH\x02\x08\x01\"$\n\nBucketById\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xe4\x01\n\x16\x41uditEventExportParams\x12\x36\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x04\x66rom\x12\x32\n\x02to\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x02to\x12\x1b\n\x06\x66ilter\x18\x03 \x01(\tB\x03\xc0J\x01R\x06\x66ilter\x12\x41\n\nevent_type\x18\x04 \x01(\x0e\x32\x1a.nebius.audit.v2.EventTypeB\x06\xbaH\x03\xc8\x01\x01R\teventType\"V\n\x16\x41uditEventExportStatus\x12<\n\x05state\x18\x01 \x01(\x0e\x32&.nebius.audit.v2.AuditEventExportStateR\x05state*\xd6\x01\n\x15\x41uditEventExportState\x12(\n$AUDIT_EVENT_EXPORT_STATE_UNSPECIFIED\x10\x00\x12$\n AUDIT_EVENT_EXPORT_STATE_RUNNING\x10\x01\x12%\n!AUDIT_EVENT_EXPORT_STATE_CANCELED\x10\x02\x12!\n\x1d\x41UDIT_EVENT_EXPORT_STATE_DONE\x10\x03\x12#\n\x1f\x41UDIT_EVENT_EXPORT_STATE_FAILED\x10\x04\x42`\n\x16\x61i.nebius.pub.audit.v2B\x15\x41uditEventExportProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.audit_event_export_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\025AuditEventExportProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _AUDITEVENTEXPORTSPEC.oneofs_by_name['export_destination']._options = None
  _AUDITEVENTEXPORTSPEC.oneofs_by_name['export_destination']._serialized_options = b'\272H\002\010\001'
  _AUDITEVENTEXPORTSPEC.fields_by_name['params']._options = None
  _AUDITEVENTEXPORTSPEC.fields_by_name['params']._serialized_options = b'\272H\003\310\001\001'
  _NEBIUSOBJECTSTORAGEDESTINATION.oneofs_by_name['bucket']._options = None
  _NEBIUSOBJECTSTORAGEDESTINATION.oneofs_by_name['bucket']._serialized_options = b'\272H\002\010\001'
  _BUCKETBYID.fields_by_name['id']._options = None
  _BUCKETBYID.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENTEXPORTPARAMS.fields_by_name['from']._options = None
  _AUDITEVENTEXPORTPARAMS.fields_by_name['from']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENTEXPORTPARAMS.fields_by_name['to']._options = None
  _AUDITEVENTEXPORTPARAMS.fields_by_name['to']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENTEXPORTPARAMS.fields_by_name['filter']._options = None
  _AUDITEVENTEXPORTPARAMS.fields_by_name['filter']._serialized_options = b'\300J\001'
  _AUDITEVENTEXPORTPARAMS.fields_by_name['event_type']._options = None
  _AUDITEVENTEXPORTPARAMS.fields_by_name['event_type']._serialized_options = b'\272H\003\310\001\001'
  _globals['_AUDITEVENTEXPORTSTATE']._serialized_start=1176
  _globals['_AUDITEVENTEXPORTSTATE']._serialized_end=1390
  _globals['_AUDITEVENTEXPORT']._serialized_start=226
  _globals['_AUDITEVENTEXPORT']._serialized_end=432
  _globals['_AUDITEVENTEXPORTSPEC']._serialized_start=435
  _globals['_AUDITEVENTEXPORTSPEC']._serialized_end=662
  _globals['_NEBIUSOBJECTSTORAGEDESTINATION']._serialized_start=665
  _globals['_NEBIUSOBJECTSTORAGEDESTINATION']._serialized_end=816
  _globals['_BUCKETBYID']._serialized_start=818
  _globals['_BUCKETBYID']._serialized_end=854
  _globals['_AUDITEVENTEXPORTPARAMS']._serialized_start=857
  _globals['_AUDITEVENTEXPORTPARAMS']._serialized_end=1085
  _globals['_AUDITEVENTEXPORTSTATUS']._serialized_start=1087
  _globals['_AUDITEVENTEXPORTSTATUS']._serialized_end=1173
# @@protoc_insertion_point(module_scope)
