# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.audit.v2 import audit_event_export_pb2 as nebius_dot_audit_dot_v2_dot_audit__event__export__pb2
from nebius.api.nebius.audit.v2 import audit_event_export_service_pb2 as nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2


class AuditEventExportServiceStub(object):
    """Service for managing audit event exports.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Start = channel.unary_unary(
                '/nebius.audit.v2.AuditEventExportService/Start',
                request_serializer=nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.StartRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Cancel = channel.unary_unary(
                '/nebius.audit.v2.AuditEventExportService/Cancel',
                request_serializer=nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.CancelRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Get = channel.unary_unary(
                '/nebius.audit.v2.AuditEventExportService/Get',
                request_serializer=nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.GetRequest.SerializeToString,
                response_deserializer=nebius_dot_audit_dot_v2_dot_audit__event__export__pb2.AuditEventExport.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.audit.v2.AuditEventExportService/List',
                request_serializer=nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.ListRequest.SerializeToString,
                response_deserializer=nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.ListAuditEventExportResponse.FromString,
                )


class AuditEventExportServiceServicer(object):
    """Service for managing audit event exports.
    """

    def Start(self, request, context):
        """Start audit events export to s3 bucket for specific period.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Cancel(self, request, context):
        """Stop active audit events export to s3 bucket, all data written before calling this API remains in the bucket.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns the audit event export with the current progress status and the parameters with which it was created.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Returns a list of exports created for a specific parent_id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuditEventExportServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.StartRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Cancel': grpc.unary_unary_rpc_method_handler(
                    servicer.Cancel,
                    request_deserializer=nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.CancelRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.GetRequest.FromString,
                    response_serializer=nebius_dot_audit_dot_v2_dot_audit__event__export__pb2.AuditEventExport.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.ListRequest.FromString,
                    response_serializer=nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.ListAuditEventExportResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.audit.v2.AuditEventExportService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AuditEventExportService(object):
    """Service for managing audit event exports.
    """

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.audit.v2.AuditEventExportService/Start',
            nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.StartRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Cancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.audit.v2.AuditEventExportService/Cancel',
            nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.CancelRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.audit.v2.AuditEventExportService/Get',
            nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.GetRequest.SerializeToString,
            nebius_dot_audit_dot_v2_dot_audit__event__export__pb2.AuditEventExport.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.audit.v2.AuditEventExportService/List',
            nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.ListRequest.SerializeToString,
            nebius_dot_audit_dot_v2_dot_audit__event__export__service__pb2.ListAuditEventExportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
